summaryrefslogtreecommitdiffstats
path: root/kdecore/ksortablevaluelist.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/ksortablevaluelist.h')
-rw-r--r--kdecore/ksortablevaluelist.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdecore/ksortablevaluelist.h b/kdecore/ksortablevaluelist.h
index fc164bf07..3f7885ca4 100644
--- a/kdecore/ksortablevaluelist.h
+++ b/kdecore/ksortablevaluelist.h
@@ -25,11 +25,11 @@
#include "kdelibs_export.h"
/**
* KSortableItem is a QPair that provides several operators
* for sorting.
* @see KSortableValueList
*/
-template<class T, class Key = int> class KSortableItem : public QPair<Key,T>
+template<class T, class Key = int> class KSortableItem : public TQPair<Key,T>
{
public:
/**
@@ -37,13 +37,13 @@ public:
* @param i the first value
* @param t the second value
*/
- KSortableItem( Key i, const T& t ) : QPair<Key, T>( i, t ) {}
+ KSortableItem( Key i, const T& t ) : TQPair<Key, T>( i, t ) {}
/**
* Creates a new KSortableItem that copies another one.
* @param rhs the other item to copy
*/
KSortableItem( const KSortableItem<T, Key> &rhs )
- : QPair<Key,T>( rhs.first, rhs.second ) {}
+ : TQPair<Key,T>( rhs.first, rhs.second ) {}
/**
* Creates a new KSortableItem with uninitialized values.
@@ -25,11 +25,11 @@
#include "kdelibs_export.h"
/**
- * KSortableItem is a QPair that provides several operators
+ * KSortableItem is a TQPair that provides several operators
* for sorting.
* @see KSortableValueList